// Copyright (c) 2003 David Muse
// See the COPYING file for more information.

#include <rudiments/private/inttypes.h>

#include <rudiments/mutex.h>
